__version__ = '3.0.5'
__api_version__ = '20.4'  # pragma: no mutate

try:
    import uvloop
except ImportError:  # pragma: no cover
    uvloop = None  # type:ignore

from .clients import AsyncClient, SyncClient
from .config import config
from .exceptions import (
    BadRequestError,
    TinvestError,
    TooManyRequestsError,
    UnexpectedError,
)
from .schemas import (
    BrokerAccountType,
    Candle,
    CandleResolution,
    Candles,
    CandlesResponse,
    CandleStreaming,
    CandleStreamingResponse,
    Currencies,
    Currency,
    CurrencyPosition,
    Empty,
    Error,
    ErrorStreaming,
    ErrorStreamingResponse,
    Event,
    InstrumentInfoStreaming,
    InstrumentInfoStreamingResponse,
    InstrumentType,
    LimitOrderRequest,
    LimitOrderResponse,
    MarketInstrument,
    MarketInstrumentList,
    MarketInstrumentListResponse,
    MarketInstrumentResponse,
    MarketOrderRequest,
    MarketOrderResponse,
    MoneyAmount,
    Operation,
    Operations,
    OperationsResponse,
    OperationStatus,
    OperationTrade,
    OperationType,
    OperationTypeWithCommission,
    Order,
    Orderbook,
    OrderbookResponse,
    OrderbookStreaming,
    OrderbookStreamingResponse,
    OrderResponse,
    OrdersResponse,
    OrderStatus,
    OrderType,
    PlacedLimitOrder,
    PlacedMarketOrder,
    Portfolio,
    PortfolioCurrenciesResponse,
    PortfolioPosition,
    PortfolioResponse,
    SandboxAccount,
    SandboxCurrency,
    SandboxRegisterRequest,
    SandboxRegisterResponse,
    SandboxSetCurrencyBalanceRequest,
    SandboxSetPositionBalanceRequest,
    SearchMarketInstrument,
    SearchMarketInstrumentResponse,
    TradeStatus,
    UserAccount,
    UserAccounts,
    UserAccountsResponse,
)
from .streaming import Streaming

if uvloop and config.USE_UVLOOP:  # pragma: no cover
    uvloop.install()

__all__ = (
    # Clients
    'AsyncClient',
    'SyncClient',
    # Errors
    'TinvestError',
    'BadRequestError',
    'TooManyRequestsError',
    'UnexpectedError',
    # Streaming
    'Streaming',
    # Streaming Schemas
    'Event',
    'InstrumentInfoStreaming',
    'OrderbookStreaming',
    'ErrorStreaming',
    'CandleStreaming',
    'InstrumentInfoStreamingResponse',
    'OrderbookStreamingResponse',
    'CandleStreamingResponse',
    'ErrorStreamingResponse',
    # Schemas
    'BrokerAccountType',
    'Candle',
    'CandleResolution',
    'Candles',
    'CandlesResponse',
    'Currencies',
    'Currency',
    'CurrencyPosition',
    'Empty',
    'Error',
    'InstrumentType',
    'LimitOrderRequest',
    'LimitOrderResponse',
    'MarketInstrument',
    'MarketInstrumentList',
    'MarketInstrumentListResponse',
    'MarketInstrumentResponse',
    'MoneyAmount',
    'MarketOrderRequest',
    'MarketOrderResponse',
    'Operation',
    'OperationStatus',
    'OperationTrade',
    'OperationType',
    'OperationTypeWithCommission',
    'Operations',
    'OperationsResponse',
    'Order',
    'OrderResponse',
    'OrderStatus',
    'OrderType',
    'Orderbook',
    'OrderbookResponse',
    'OrdersResponse',
    'PlacedLimitOrder',
    'Portfolio',
    'PortfolioCurrenciesResponse',
    'PortfolioPosition',
    'PortfolioResponse',
    'PlacedMarketOrder',
    'SandboxAccount',
    'SandboxCurrency',
    'SandboxSetCurrencyBalanceRequest',
    'SandboxSetPositionBalanceRequest',
    'SandboxRegisterRequest',
    'SandboxRegisterResponse',
    'SearchMarketInstrument',
    'SearchMarketInstrumentResponse',
    'TradeStatus',
    'UserAccount',
    'UserAccounts',
    'UserAccountsResponse',
)
